

using System.Collections.Generic;

namespace FitConnect.Models;

public class Destination {
    public string LeikaKey { get; set; }
    public string? Ags { get; set; }
    public string? Ars { get; set; }
    public string? AreaId { get; set; }
    public string DestinationId { get; set; }

    public bool Valid => !((string.IsNullOrWhiteSpace(Ags)
                            && string.IsNullOrWhiteSpace(Ars)
                            && string.IsNullOrWhiteSpace(AreaId)) ||
                           string.IsNullOrWhiteSpace(LeikaKey));
}

public class Submission {
    public string Id { get; set; }
    public string? CaseId { get; set; }
    public Destination Destination { get; set; } = new Destination();

    public string DestinationId {
        get => Destination.DestinationId;
        set => Destination.DestinationId = value;
    }

    public List<Attachment> Attachments { get; set; } = new();

    public ServiceType ServiceType { get; init; }

    public Callback? Callback { get; set; }
    public Metadata? Metadata { get; set; }
    public Data? Data { get; set; }
    public string EncryptedMetadata { get; set; }
    public string EncryptedData { get; set; }

    public bool IsSubmissionReadyToAdd(out string? error) {
        var innerError = "";
        if (string.IsNullOrEmpty(DestinationId)) innerError += "DestinationId is required\r\n";

        if (ServiceType.IsValid()) innerError += "ServiceType is invalid\r\n";

        if (string.IsNullOrWhiteSpace(innerError)) {
            error = null;
            return true;
        }

        error = innerError.Trim();
        return false;
    }

    public bool IsSubmissionReadyToSend() {
        return true;
    }

}
